<?php

require_once ('DatabaseConnector.php');
require_once ('CompanyResolver.php');
require_once ('CompanyMapper.php');
require_once ('CompanyQueryBuilder.php');
require_once ('CompanyPersister.php');

try {
    $databaseConnector = new DatabaseConnector();
    $companyResolver = new CompanyResolver($databaseConnector, ['AS']);
    $companyMapper = new CompanyMapper($companyResolver);
    $companyQueryBuilder = new CompanyQueryBuilder();
    $companyPersister = new CompanyPersister($databaseConnector, $companyQueryBuilder);
} catch (Exception $e) {
    var_dump($e->getMessage());
    exit;
}

$dir = new DirectoryIterator(dirname(__FILE__).'/imports');
foreach ($dir as $fileinfo) {
    if ($fileinfo->getExtension() == 'xml') {
        $fileName = 'imports/' . $fileinfo->getFilename();
        if (!file_exists($fileName)) {
            echo("Could not find file. $fileName");
            exit;
        }
        $xmlFile = file_get_contents($fileName);
        $data = new SimpleXMLElement($xmlFile);

        foreach ($data->del as $company) {
            $resultArray = $companyMapper->mapDataToArray($company, $fileName);
            if ($resultArray) {
                try {
                    $companyPersister->persistCompanyData($resultArray);
                } catch (Exception $e) {
                    var_dump($e->getMessage());
                    exit;
                }
            }
        }
    }
}

$databaseConnector->close();
echo("DONE\n");
var_dump(microtime(true) - $time_start);
